@@ -458,6 +458,9 @@ RESOURCEINUSE = 'ResourceInUse'
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
+# 网段资源不足。
+RESOURCEINSUFFICIENT_CIDRBLOCK = 'ResourceInsufficient.CidrBlock'
+
 # IP资源不足。
 RESOURCEINSUFFICIENT_IPQUOTANOTENOUGH = 'ResourceInsufficient.IPQuotaNotEnough'
 
@@ -467,6 +470,9 @@ RESOURCEINSUFFICIENT_INSTANCEQUOTANOTENOUGH = 'ResourceInsufficient.InstanceQuot
 # 私有镜像数量超出限制。
 RESOURCEINSUFFICIENT_INVAILDPRIVATEIMAGENUM = 'ResourceInsufficient.InvaildPrivateImageNum'
 
+# 当前子网中内网IP不足
+RESOURCEINSUFFICIENT_PRIVATEIPQUOTANOTENOUGH = 'ResourceInsufficient.PrivateIPQuotaNotEnough'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
